@@ -163,7 +163,7 @@ from ae.core import DEBUG_LEVEL_VERBOSE
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action   # type: ignore
 
 
-__version__ = '0.0.11'
+__version__ = '0.0.12'
 
 
 FLOW_PATH_ROOT_ID = '<<<root>>>'     #: needed for flow path jumper and for drop onto leave item button
@@ -723,33 +723,40 @@ class LiszDataMixin(ABC):
             if 'node' in item:
                 self.shrink_node_size(item['node'])
 
-    def sub_item_ids(self, item_id, node_only, node=None, sub_item_ids=None) -> List[str]:
+    def sub_item_ids(self, item_id: str, leafs_only: bool, hide_sel_val: Optional[bool] = None,
+                     node: Optional[LiszNode] = None, sub_ids: Optional[List[str]] = None) -> List[str]:
         """ return item names of all items including their sub-node items (if exists).
 
-        Used for to determine the affected items if user want to delete the item specified by item_id.
+        Used for to determine the affected items if user want to delete or de-/select the sub-items of
+        the node item specified by the :paramref:`sub_item_ids.item_id` argument.
 
-        :param item_id:         item id of the item to be deleted.
-        :param node_only:       True if only include the item ids of the sub-nodes of the identified item.
+        :param item_id:         item id of the node item to be investigated (for to be deleted or de-/selected later).
+        :param leafs_only:      True if only include the leaf item ids of the sub-nodes of the node item.
+        :param hide_sel_val:    pass False/True for to exclude un-/selected items from the returned list of ids.
+                                If None or not passed then all found items will be included.
         :param node:            searched node, use current node if not passed (used for recursive calls of this method).
-        :param sub_item_ids:    already found sub item ids (used only for the recursive calls of this method).
+        :param sub_ids:         already found sub item ids (used only for the recursive calls of this method).
         :return:                list of found item ids.
         """
         if node is None:
             node = self.current_node_items
-        if sub_item_ids is None:
-            sub_item_ids = list()
+        if sub_ids is None:
+            sub_ids = list()
 
-        if not node_only:
-            sub_item_ids.append(item_id)
+        item = self.item_by_id(item_id, node)
 
-        node = self.item_by_id(item_id, node).get('node', list())
-        for nid in node:
-            if nid.get('node'):
-                self.sub_item_ids(nid['id'], False, node, sub_item_ids)
-            else:
-                sub_item_ids.append(nid['id'])
+        if not leafs_only and (hide_sel_val is None or bool(item.get('sel')) != hide_sel_val):
+            sub_ids.append(item_id)
 
-        return sub_item_ids
+        node = item.get('node')
+        if node is not None:
+            for item in node:
+                if item.get('node'):
+                    self.sub_item_ids(item['id'], leafs_only, hide_sel_val=hide_sel_val, node=node, sub_ids=sub_ids)
+                elif hide_sel_val is None or bool(item.get('sel')) != hide_sel_val:
+                    sub_ids.append(item['id'])
+
+        return sub_ids
 
     def toggle_item_sel(self, node_idx: int):
         """ toggle the item selection of the item identified by the list index in the current node.
